@@ -13,18 +13,23 @@
 
 #include <cmath>
 
-// Behaves like qBound, which behaves differently from std::clamp,
-// but uses the same argument order as std::clamp.
-// We don't use qBound or std::clamp because we don't want asserts.
-constexpr static inline qreal clamp(qreal value, qreal min, qreal max) noexcept
+class GeometrySingleton
 {
-    return std::max(min, std::min(value, max));
-}
+public:
+    Geometry self;
+};
+
+Q_GLOBAL_STATIC(GeometrySingleton, privateGeometrySelf)
 
 Geometry::Geometry(QObject *parent)
     : QObject(parent)
 {}
 
+Geometry *Geometry::instance()
+{
+    return &privateGeometrySelf->self;
+}
+
 qreal Geometry::dpx(qreal dpr)
 {
     return 1 / dpr;
@@ -35,21 +40,6 @@ qreal Geometry::dprRound(qreal value, qreal dpr)
     return std::round(value * dpr) / dpr;
 }
 
-QPointF Geometry::dprRound(QPointF point, qreal dpr)
-{
-    return {std::round(point.x() * dpr) / dpr, std::round(point.y() * dpr) / dpr};
-}
-
-qreal Geometry::dprCeil(qreal value, qreal dpr)
-{
-    return std::ceil(value * dpr) / dpr;
-}
-
-qreal Geometry::dprFloor(qreal value, qreal dpr)
-{
-    return std::floor(value * dpr) / dpr;
-}
-
 qreal Geometry::mapFromPlatformValue(qreal value, qreal dpr)
 {
     if (KWindowSystem::isPlatformX11()) {
@@ -125,16 +115,6 @@ QSize Geometry::rawSize(const QSizeF &size, qreal dpr)
     return (size * dpr).toSize();
 }
 
-QRectF Geometry::rectNormalized(const QRectF &rect)
-{
-    return rect.normalized();
-}
-
-QRectF Geometry::rectNormalized(qreal x, qreal y, qreal w, qreal h)
-{
-    return QRectF(x, y, w, h).normalized();
-}
-
 QRectF Geometry::rectAdjusted(const QRectF &rect, qreal xp1, qreal yp1, qreal xp2, qreal yp2)
 {
     return rect.adjusted(xp1, yp1, xp2, yp2);
@@ -153,10 +133,7 @@ QRectF Geometry::rectAdjustedVisually(const QRectF &rect, qreal xp1, qreal yp1,
 
 QRectF Geometry::rectScaled(const QRectF &rect, qreal scale)
 {
-    if (scale == 1) {
-        return rect;
-    }
-    return {rect.topLeft() * scale, rect.size() * scale};
+    return {rect.topLeft() * scale, rect.size() *scale};
 }
 
 QRectF Geometry::rectIntersected(const QRectF &rect1, const QRectF &rect2)
@@ -174,27 +151,21 @@ QRectF Geometry::rectBounded(const QRectF &rect, const QRectF &boundsRect,
     const auto &nBoundsRect = boundsRect.normalized(); // normalize to make math easier
     if (orientations & Qt::Horizontal) {
         if (rect.width() >= 0) {
-            newRect.moveLeft(clamp(rect.x(), nBoundsRect.x(), nBoundsRect.right() - rect.width()));
+            newRect.moveLeft(std::clamp(rect.x(), nBoundsRect.x(), nBoundsRect.right() - rect.width()));
         } else {
-            newRect.moveRight(clamp(rect.right(), nBoundsRect.x(), nBoundsRect.right() - std::abs(rect.width())));
+            newRect.moveRight(std::clamp(rect.right(), nBoundsRect.x(), nBoundsRect.right() - std::abs(rect.width())));
         }
     }
     if (orientations & Qt::Vertical) {
         if (rect.height() >= 0) {
-            newRect.moveTop(clamp(rect.y(), nBoundsRect.y(), nBoundsRect.bottom() - std::abs(rect.height())));
+            newRect.moveTop(std::clamp(rect.y(), nBoundsRect.y(), nBoundsRect.bottom() - std::abs(rect.height())));
         } else {
-            newRect.moveBottom(clamp(rect.bottom(), nBoundsRect.y(), nBoundsRect.bottom() - std::abs(rect.height())));
+            newRect.moveBottom(std::clamp(rect.bottom(), nBoundsRect.y(), nBoundsRect.bottom() - std::abs(rect.height())));
         }
     }
     return newRect;
 }
 
-QRectF Geometry::rectBounded(qreal x, qreal y, qreal width, qreal height, const QRectF &boundsRect,
-                             Qt::Orientations orientations)
-{
-    return rectBounded({x, y, width, height}, boundsRect, orientations);
-}
-
 QRectF Geometry::rectClipped(const QRectF &rect, const QRectF &clipRect,
                              Qt::Orientations orientations)
 {
