@@ -147,7 +147,7 @@ SpectacleCore::SpectacleCore(QObject *parent)
             // deleteWindows();
             // showViewerIfGuiMode(true);
             bool includePointer = m_cliOptions[CommandLineOptions::Pointer];
-            includePointer |= m_startMode != StartMode::Background && Settings::includePointer();
+            includePointer |= m_startMode != StartMode::Background && Settings::videoIncludePointer();
             const auto &output = m_outputUrl.isLocalFile() ? videoOutputUrl() : QUrl();
             m_videoPlatform->startRecording(output, VideoPlatform::Region, rect.toRect(), includePointer);
         } else {
@@ -269,7 +269,13 @@ SpectacleCore::SpectacleCore(QObject *parent)
     }, Qt::QueuedConnection); // QueuedConnection to help prevent making the visible render lag.
 
     // set up shortcuts
-    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->openAction(), Qt::Key_Print);
+    KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->openAction(),
+                                            QList<QKeySequence>{
+                                                Qt::Key_Print,
+                                                // Default screenshot shortcut on Windows.
+                                                // Also for keyboards without a print screen key.
+                                                Qt::META | Qt::SHIFT | Qt::Key_S,
+                                            });
     KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->fullScreenAction(), Qt::SHIFT | Qt::Key_Print);
     KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->activeWindowAction(), Qt::META | Qt::Key_Print);
     KGlobalAccel::self()->setGlobalShortcut(ShortcutActions::self()->windowUnderCursorAction(), Qt::META | Qt::CTRL | Qt::Key_Print);
@@ -483,9 +489,8 @@ void SpectacleCore::activate(const QStringList &arguments, const QString &workin
     }
 
     // reset last region if it should not be remembered across restarts
-    if (!(Settings::rememberLastRectangularRegion() == Settings::EnumRememberLastRectangularRegion::Always)) {
-        // QRect defaults to {0,0,-1,-1} while QRectF defaults to {0,0,0,0}.
-        Settings::setCropRegion({0, 0, 0, 0});
+    if (!(Settings::rememberSelectionRect() == Settings::EnumRememberSelectionRect::Always)) {
+        Settings::setSelectionRect({0, 0, 0, 0});
     }
 
     /* The logic for setting options for each start mode:
@@ -602,6 +607,10 @@ void SpectacleCore::activate(const QStringList &arguments, const QString &workin
             return;
         }
         setVideoMode(true);
+
+        if (m_startMode != StartMode::Background) {
+            includePointer = Settings::videoIncludePointer() || m_cliOptions[Option::Pointer];
+        }
     } else {
         setVideoMode(false);
     }
@@ -643,8 +652,8 @@ void SpectacleCore::activate(const QStringList &arguments, const QString &workin
                 }
             }
         } else {
-            using Actions = Settings::EnumPrintKeyActionRunning;
-            switch (Settings::printKeyActionRunning()) {
+            using Actions = Settings::EnumPrintKeyRunningAction;
+            switch (Settings::printKeyRunningAction()) {
             case Actions::TakeNewScreenshot: {
                 // takeNewScreenshot switches to on click if immediate is not supported.
                 takeNewScreenshot(grabMode, 0, includePointer, includeDecorations, includeShadow);
